==> hs-HaXml-1.23.3p2.tgz: lib/ghc/HaXml-1.23.3/register.sh <==
#!/bin/sh
echo 'name: HaXml
version: 1.23.3
id: HaXml-1.23.3-78bec04b0d1e459ca536ec2924dd9cdf

license: LGPL
copyright:
maintainer: author
stability:
homepage: http://www.cs.york.ac.uk/fp/HaXml/
package-url:
synopsis: Utilities for manipulating XML documents
description: Haskell utilities for parsing, filtering, transforming and
             generating XML documents.
category: Text, XML
author: Malcolm Wallace <Malcolm.Wallace@me.com>
pkgpath: textproc/hs-HaXml
exposed: True
exposed-modules: Text.XML.HaXml.Schema.Schema Text.XML.HaXml
                 Text.XML.HaXml.ByteStringPP Text.XML.HaXml.Combinators
                 Text.XML.HaXml.DtdToHaskell.Convert
                 Text.XML.HaXml.DtdToHaskell.Instance
                 Text.XML.HaXml.DtdToHaskell.TypeDef Text.XML.HaXml.Escape
                 Text.XML.HaXml.Html.Generate Text.XML.HaXml.Html.Parse
                 Text.XML.HaXml.Html.ParseLazy Text.XML.HaXml.Html.Pretty
                 Text.XML.HaXml.Lex Text.XML.HaXml.Namespaces Text.XML.HaXml.OneOfN
                 Text.XML.HaXml.Parse Text.XML.HaXml.ParseLazy Text.XML.HaXml.Posn
                 Text.XML.HaXml.Pretty Text.XML.HaXml.SAX
                 Text.XML.HaXml.Schema.Parse Text.XML.HaXml.Schema.XSDTypeModel
                 Text.XML.HaXml.Schema.HaskellTypeModel
                 Text.XML.HaXml.Schema.NameConversion
                 Text.XML.HaXml.Schema.TypeConversion
                 Text.XML.HaXml.Schema.PrettyHaskell
                 Text.XML.HaXml.Schema.PrettyHsBoot
                 Text.XML.HaXml.Schema.PrimitiveTypes
                 Text.XML.HaXml.Schema.Environment Text.XML.HaXml.ShowXmlLazy
                 Text.XML.HaXml.Types Text.XML.HaXml.TypeMapping Text.XML.HaXml.Util
                 Text.XML.HaXml.Validate Text.XML.HaXml.Verbatim
                 Text.XML.HaXml.Wrappers Text.XML.HaXml.XmlContent
                 Text.XML.HaXml.XmlContent.Parser Text.XML.HaXml.XmlContent.Haskell
                 Text.XML.HaXml.Xtract.Combinators Text.XML.HaXml.Xtract.Lex
                 Text.XML.HaXml.Xtract.Parse
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/HaXml-1.23.3
library-dirs: /usr/local/lib/ghc/HaXml-1.23.3
hs-libraries: HSHaXml-1.23.3
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.5.1.0-5b1c9d3d412ed227632edae6d2aca151
         bytestring-0.9.2.1-3c5b69d9d36e3a0179d120b97025ab86
         containers-0.4.2.1-efa59805336a77490296ae3897cecb87
         directory-1.1.0.2-4b2070a8941d5c76e41241a2ac457927
         filepath-1.3.0.0-954c43b4f109cbd4121f1231c14d5cff
         polyparse-1.7-8a41a8943e1f540834819340290e5480
         pretty-1.1.1.0-867dcdeb02592f3d2a707618561c7b86
         random-1.0.1.1-597e5fbb16214a2d52b559b0643d1749
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-HaXml-1.23.3/html/HaXml.haddock
haddock-html: /usr/local/share/doc/hs-HaXml-1.23.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-HaXml-1.24.tgz: lib/ghc/HaXml-1.24/register.sh <==
#!/bin/sh
echo 'name: HaXml
version: 1.24
id: HaXml-1.24-ab4d74082e9de2483ebda74273c4c324

license: LGPL
copyright:
maintainer: author
stability:
homepage: http://www.cs.york.ac.uk/fp/HaXml/
package-url:
synopsis: Utilities for manipulating XML documents
description: Haskell utilities for parsing, filtering, transforming and
             generating XML documents.
category: Text, XML
author: Malcolm Wallace <Malcolm.Wallace@me.com>
pkgpath: textproc/hs-HaXml
exposed: True
exposed-modules: Text.XML.HaXml.Schema.Schema Text.XML.HaXml
                 Text.XML.HaXml.ByteStringPP Text.XML.HaXml.Combinators
                 Text.XML.HaXml.DtdToHaskell.Convert
                 Text.XML.HaXml.DtdToHaskell.Instance
                 Text.XML.HaXml.DtdToHaskell.TypeDef Text.XML.HaXml.Escape
                 Text.XML.HaXml.Html.Generate Text.XML.HaXml.Html.Parse
                 Text.XML.HaXml.Html.ParseLazy Text.XML.HaXml.Html.Pretty
                 Text.XML.HaXml.Lex Text.XML.HaXml.Namespaces Text.XML.HaXml.OneOfN
                 Text.XML.HaXml.Parse Text.XML.HaXml.ParseLazy Text.XML.HaXml.Posn
                 Text.XML.HaXml.Pretty Text.XML.HaXml.SAX
                 Text.XML.HaXml.Schema.Parse Text.XML.HaXml.Schema.XSDTypeModel
                 Text.XML.HaXml.Schema.HaskellTypeModel
                 Text.XML.HaXml.Schema.NameConversion
                 Text.XML.HaXml.Schema.TypeConversion
                 Text.XML.HaXml.Schema.PrettyHaskell
                 Text.XML.HaXml.Schema.PrettyHsBoot
                 Text.XML.HaXml.Schema.PrimitiveTypes
                 Text.XML.HaXml.Schema.Environment Text.XML.HaXml.ShowXmlLazy
                 Text.XML.HaXml.Types Text.XML.HaXml.TypeMapping Text.XML.HaXml.Util
                 Text.XML.HaXml.Validate Text.XML.HaXml.Verbatim
                 Text.XML.HaXml.Wrappers Text.XML.HaXml.XmlContent
                 Text.XML.HaXml.XmlContent.Parser Text.XML.HaXml.XmlContent.Haskell
                 Text.XML.HaXml.Xtract.Combinators Text.XML.HaXml.Xtract.Lex
                 Text.XML.HaXml.Xtract.Parse
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/HaXml-1.24
library-dirs: /usr/local/lib/ghc/HaXml-1.24
hs-libraries: HSHaXml-1.24
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
         bytestring-0.10.0.2-9e8b487747800a4255d6ff7915c5210f
         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
         directory-1.2.0.1-ee04c884b72040489d2e2ca6dd62e6ac
         filepath-1.3.0.1-b12cbe18566fe1532a1fda4c85e31cbe
         polyparse-1.9-b5f5bd214b1b2a7afc4372c48e61bd4a
         pretty-1.1.1.0-66181c695e6a2e173ba2088cf55cc396
         random-1.0.1.1-023a342365721422ffd5a919bc8708bb
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-HaXml-1.24/html/HaXml.haddock
haddock-html: /usr/local/share/doc/hs-HaXml-1.24/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
